Package 2048 - Projet informatique de 1er semestre ENSAE
========================================================

Ce module propose une fonction pour résoudre le 2048.
La fonction adeterminer résout le 2048 en utilisant la stratégie du snake (a dévelloper)
Afin de juger de l'efficacité de cette algorithme, vous pouvez utiliser la fonction evaluate_strategy qui prend en argument la
fonction adeterminer et le nombre de parties effectuées.

Comment notre programme résout-il le 2048 ?
-------------------------------------------

Blablabla

Comment pouvez-vous effectuer le test de nos fonctions ?
--------------------------------------------------------

Blablabla

Quelques commandes utiles.
--------------------------

Ce module peut être installé avec pip :

    pip install pack2048

Exemple d'usage :

    >>> from pack2048 import evaluate_strategy, adeterminer
    >>> evaluate_strategy(adeterminer,10)

Les tests doivent être effectués en console :

    python -m pack2048

Ce code est sous licence GNU AGPLv3.